@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
 our $DATE = '2016-09-28'; # DATE
-our $VERSION = '0.65'; # VERSION
+our $VERSION = '0.66'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -325,6 +325,7 @@ sub _process_script {
                 $cmdline =~ s/\[\[prog\]\]/$prog/;
                 push @content, " % $cmdline\n";
 
+                my $show_result;
               SHOW_RESULT:
                 {
                     my $fres;
@@ -384,6 +385,11 @@ sub _process_script {
                     $fres =~ s/^/ /gm;
                     push @content, $fres;
                     push @content, "\n";
+                    $show_result = 1;
+                } # SHOW_RESULT
+
+                unless ($show_result) {
+                    push @content, "\n";
                 }
             }
         }
@@ -885,7 +891,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.65 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-28.
+This document describes version 0.66 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-28.
 
 =head1 SYNOPSIS
 
